# ProtoDriverPI
A simple Raspberry Pi web api for driving a MAX7219 dot matrix display

This packege is meant to be ran as a REST API and be called from a dedicated frontend.

ProtoDriverPI has only just been brought to a useable level and is in no way production ready.